netapp_ontap.resources.disk API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.disk`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Retrieving storage disk information

The storage disk GET API retrieves all of the disks in the cluster.

## Examples

### 1) Retrieve a list of disks from the cluster.

#### The following example shows the response with a list of disks in the cluster:

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Disk

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(Disk.get_collection()))

Try it out

    [
        Disk({"name": "1.24.4"}),
        Disk({"name": "1.24.3"}),
        Disk({"name": "1.24.5"}),
        Disk({"name": "1.24.0"}),
        Disk({"name": "1.24.2"}),
        Disk({"name": "1.24.1"}),
    ]

### 2) Retrieve a specific disk from the cluster.

#### The following example shows the response of the requested disk. If there is no disk with the requested name, an error is returned:

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Disk

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Disk(name="1.24.3")
        resource.get()
        print(resource)

Try it out

    Disk(
        {
            "serial_number": "EC47PC5021SW",
            "effective_type": "sas",
            "name": "1.24.3",
            "aggregates": [
                {
                    "_links": {
                        "self": {
                            "href": "/api/storage/aggregates/3fd9c345-ba91-4949-a7b1-6e2b898d74e3"
                        }
                    },
                    "name": "node_2_SAS_1",
                    "uuid": "3fd9c345-ba91-4949-a7b1-6e2b898d74e3",
                }
            ],
            "paths": [
                {
                    "initiator": "3a",
                    "port_name": "B",
                    "wwpn": "5000cca02f0e676a",
                    "port_type": "sas",
                    "wwnn": "5000cca02f0e6768",
                },
                {
                    "initiator": "3d",
                    "port_name": "A",
                    "wwpn": "5000cca02f0e6769",
                    "port_type": "sas",
                    "wwnn": "5000cca02f0e6768",
                },
                {
                    "initiator": "3d",
                    "port_name": "A",
                    "wwpn": "5000cca02f0e6769",
                    "port_type": "sas",
                    "wwnn": "5000cca02f0e6768",
                },
                {
                    "initiator": "3a",
                    "port_name": "B",
                    "wwpn": "5000cca02f0e676a",
                    "port_type": "sas",
                    "wwnn": "5000cca02f0e6768",
                },
            ],
            "node": {
                "name": "node-2",
                "_links": {
                    "self": {
                        "href": "/api/cluster/nodes/3a89ed49-8c6d-11e8-93bc-00a0985a64b6"
                    }
                },
                "uuid": "3a89ed49-8c6d-11e8-93bc-00a0985a64b6",
            },
            "error": [
                {
                    "reason": {
                        "message": '"The node is configured with All-Flash Optimized personality and this disk is not an SSD. The disk needs to be removed from the system."',
                        "code": "721082",
                    },
                    "type": "notallflashdisk",
                }
            ],
            "vendor": "NETAPP",
            "container_type": "aggregate",
            "usable_size": 438304768000,
            "right_size_sector_count": 5579776,
            "pool": "pool0",
            "home_node": {
                "name": "node-2",
                "_links": {
                    "self": {
                        "href": "/api/cluster/nodes/3a89ed49-8c6d-11e8-93bc-00a0985a64b6"
                    }
                },
                "uuid": "3a89ed49-8c6d-11e8-93bc-00a0985a64b6",
            },
            "bay": 3,
            "state": "present",
            "shelf": {"uid": "10318311901725526608"},
            "physical_size": 438804988000,
            "outage": {
                "reason": {
                    "message": 'Failed disk. Reason: "admin failed".',
                    "code": "721081",
                },
                "persistently_failed": True,
            },
            "model": "X421_FAL12450A10",
            "bytes_per_sector": 512,
            "uid": "50000394:0808AA88:00000000:00000000:00000000:00000000:00000000:00000000:00000000:00000000",
            "local": True,
            "type": "sas",
            "stats": {
                "average_latency": 6,
                "power_on_hours": 11797,
                "throughput": 1957888,
                "path_error_count": 0,
                "iops_total": 12854,
            },
            "rpm": 10000,
            "firmware_version": "NA02",
            "sector_count": 1172123568,
            "class": "performance",
        }
    )

### 3) Retrieving a specific disk from the hypervisor

#### The following example shows the response of the requested disk. If there is no disk with the requested name, an error is returned:

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Disk

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Disk(name="NET-3.2")
        resource.get()
        print(resource)

Try it out

    Disk(
        {
            "serial_number": "3234363765386464",
            "name": "NET-3.2",
            "paths": [
                {
                    "initiator": "0f",
                    "port_name": "A",
                    "wwpn": "53059d50444f5476",
                    "vmdisk_hypervisor_file_name": "LUN 4.0",
                    "port_type": "sas",
                    "wwnn": "53059d50444f5476",
                },
                {
                    "initiator": "0f",
                    "port_name": "A",
                    "wwpn": "53059d50444f5476",
                    "vmdisk_hypervisor_file_name": "LUN 2.0",
                    "port_type": "sas",
                    "wwnn": "53059d50444f5476",
                },
            ],
            "node": {
                "name": "example_node_name",
                "_links": {
                    "self": {
                        "href": "/api/cluster/nodes/f4cb78ba-5841-11ec-80c4-916f62b4cd44"
                    }
                },
                "uuid": "f4cb78ba-5841-11ec-80c4-916f62b4cd44",
            },
            "vendor": "NETAPP",
            "container_type": "mediator",
            "fips_certified": False,
            "right_size_sector_count": 5579776,
            "pool": "pool0",
            "home_node": {
                "name": "example_node_name",
                "_links": {
                    "self": {
                        "href": "/api/cluster/nodes/f4cb78ba-5841-11ec-80c4-916f62b4cd44"
                    }
                },
                "uuid": "f4cb78ba-5841-11ec-80c4-916f62b4cd44",
            },
            "self_encrypting": False,
            "physical_size": 204808,
            "outage": {
                "reason": {"message": 'Failed disk. Reason: "".', "code": "721081"},
                "persistently_failed": False,
            },
            "model": "PHA-DISK",
            "bytes_per_sector": 512,
            "uid": "32343637:65386464:00000000:00000000:00000000:00000000:00000000:00000000:00000000:00000000",
            "local": True,
            "type": "vmdisk",
            "stats": {
                "average_latency": 2157188883,
                "power_on_hours": 0,
                "throughput": 4096,
                "path_error_count": 0,
                "iops_total": 1,
            },
            "firmware_version": "0001",
            "sector_count": 204808,
            "class": "virtual",
        }
    )

## Modifying storage disk

The storage disk PATCH API modifies disk ownership, unfails a disk, updates encrypting drive authentication keys (AKs), sanitizes encrypting drives, or sanitizes non-encrypting spare drives in the cluster. The storage disk API currently supports patching one attribute at a time.

### Updating the disk ownership for a specified disk. Disk ownership cannot be updated on the ASA r2 platform.

### 1. When the disk is not assigned

When the disk is a spare (or unowned) disk and node name is specified, the PATCH operation assigns the disk to the specified node. Optionally, pool name can also be specified along with node name. Accepted pool names are: pool0, pool1.

### 2. When the disk is already assigned

When the disk is already assigned (already has a owner), and a new node is specified, the PATCH operation changes the ownership to the new node. Optionally, pool name can also be specified along with node name. Accepted pool names are: pool0, pool1.

### Removing the disk ownership for a specified disk

When the disk is already assigned, and node name is specified as null (no-quotes), the PATCH operation removes the owner.

## Examples

### 1. Update the disk ownership for an unowned disk

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Disk

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Disk()
        resource.node = {"name": "node-name"}
        resource.patch(hydrate=True, name="<disk-name>")

### 2. Update the disk ownership for an already owned disk

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Disk

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Disk()
        resource.node = {"name": "node-name"}
        resource.patch(hydrate=True, name="<disk-name>")

### 3. Update the disk pool for a disk (can be either owned or unowned).

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Disk

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Disk()
        resource.node = {"name": "node-name"}
        resource.pool = "pool0"
        resource.patch(hydrate=True, name="<disk-name>")

### 4. Rekey the data authentication key (AK) of all encrypting drives to an authentication key (AK) selected automatically by the system

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Disk

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Disk()
        resource.patch(hydrate=True, name="*", encryption_operation="rekey_data_auto_id")

### 5. Cryptographically sanitize a spare or broken disk

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Disk

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Disk()
        resource.patch(
            hydrate=True, name="<disk-name>", encryption_operation="sanitize_disk"
        )

### 6. Unfailing a disk to a spare.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Disk

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Disk()
        resource.state = "spare"
        resource.patch(hydrate=True, name="<disk-name>")

### 7. Unfailing a disk and attempting to reassimilate filesystem labels.

### If unable or unnecessary to reassimilate filesystem labels, the disk will be set as spare.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Disk

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Disk()
        resource.state = "present"
        resource.patch(hydrate=True, name="<disk-name>")

### 8. Sanitize spare disks (non-cryptographically)

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Disk

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Disk()
        resource.sanitize_spare = True
        resource.patch(hydrate=True, name="<disk-name>")

## Classes

`class Disk (*args, **kwargs)`

  Allows interaction with Disk objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection (*args, connection: HostConnection = None, **kwargs) -> int`

    Returns a count of all Disk resources that match the provided query

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def fast_get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[RawResource]`

    Returns a list of RawResources that represent Disk resources that match the provided query

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def find (*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves a collection of disks.

    ### Related ONTAP commands

    - `storage disk show`

    ### Learn more

    - `DOC /storage/disks`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[Resource]`

    Retrieves a collection of disks.

    ### Related ONTAP commands

    - `storage disk show`

    ### Learn more

    - `DOC /storage/disks`

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection (body: dict, *args, records: Iterable[ForwardRef('Disk')] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates disk ownership, changes authentication keys, sanitizes encrypting disks, or sanitizes non-encrypting spare disks.

    ### Related ONTAP commands

    - `storage disk assign`
    - `storage disk removeowner`
    - `storage encryption disk modify -data-key-id`
    - `storage encryption disk sanitize`
    - `security key-manager key query -key-type NSE-AK`
    - `storage disk unfail`
    - `storage disk sanitize-spare`

    ### Learn more

    - `DOC /storage/disks`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection. The body argument will be ignored if records is provided.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be patched on the host.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves a specific disk.

    ### Related ONTAP commands

    - `storage disk show`
    - `storage encryption disk show`

    ### Learn more

    - `DOC /storage/disks`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class DiskSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the Disk object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `aggregates: List[ContainerVolumeExcludeAggregates] GET`

    List of aggregates sharing this disk

  `bay: Size GET`

    Disk shelf bay

    Example: 1

  `bytes_per_sector: Size GET`

    Bytes per sector.

    Example: 520

  `class_: str GET`

    Disk class

    Valid choices:

    - unknown
    - capacity
    - performance
    - archive
    - solid_state
    - array
    - virtual
  `compliance_standard: str GET`

    Security standard that the device is certified to.

    Example: FIPS 140-2

  `container_type: str GET`

    Type of overlying disk container

    Valid choices:

    - aggregate
    - broken
    - foreign
    - labelmaint
    - maintenance
    - shared
    - spare
    - unassigned
    - unknown
    - unsupported
    - remote
    - mediator
  `control_standard: str GET`

    Standard that the device supports for encryption control.

    Example: TCG Enterprise

  `dr_node: DrNode GET`

    The dr_node field of the disk.

  `drawer: DiskDrawer GET`

    The drawer field of the disk.

  `effective_type: str GET`

    Effective Disk type

    Valid choices:

    - ata
    - fcal
    - lun
    - msata
    - sas
    - bsas
    - ssd
    - ssd_nvm
    - ssd_zns
    - ssd_cap
    - fsas
    - vmdisk
    - unknown
  `encryption_operation: str PATCH`

    This field should only be set as a query parameter in a PATCH operation. It is input only and won't be returned by a subsequent GET.

  `error: List[DiskErrorInfo] GET`

    List of disk errors information.

  `fips_certified: bool GET`

    The fips_certified field of the disk.

  `firmware_version: str GET`

    The firmware_version field of the disk.

    Example: NA51

  `home_node: Node GET`

    The home_node field of the disk.

  `key_id: DiskKeyId GET`

    The key_id field of the disk.

  `local: bool GET`

    Indicates if a disk is locally attached versus being remotely attached. A locally attached disk resides in the same proximity as the host cluster versus been attached to the remote cluster.

  `location: str GET`

    Physical location of the disk

    Example: node-01

  `model: str GET`

    The model field of the disk.

    Example: X421_HCOBE450A10

  `name: str GET`

    Cluster-wide disk name

    Example: 1.0.1

  `node: Node GET PATCH`

    The node field of the disk.

  `outage: DiskOutage GET POST PATCH`

    Indicates if a disk has an entry in the failed disk registry, along with the reason for the failure.

  `overall_security: str GET`

    Overall Security rating, for FIPS-certified devices.

    Example: Level 2

  `paths: List[DiskPathInfo] GET`

    List of paths to a disk

  `physical_size: Size GET`

    Physical size, in units of bytes

    Example: 228930

  `pool: str GET PATCH`

    Pool to which disk is assigned

    Valid choices:

    - pool0
    - pool1
    - failed
    - none
  `protection_mode: str GET`

    Mode of drive data protection and FIPS compliance. Possible values are: - open - Data is unprotected - data - Data protection only, without FIPS compliance - part - Data is unprotected; other FIPS compliance settings present - full - Full data and FIPS compliance protection - miss - Protection mode information is not available

    Valid choices:

    - open
    - data
    - part
    - full
    - miss
  `rated_life_used_percent: Size GET`

    Percentage of rated life used

    Example: 10

  `right_size_sector_count: Size GET`

    Number of usable disk sectors that remain after subtracting the right-size adjustment for this disk.

    Example: 1172123568

  `rpm: Size GET`

    Revolutions per minute

    Example: 15000

  `sanitize_spare: bool PATCH`

    Confirms spare disk sanitization (non-cryptographically).

  `sector_count: Size GET`

    Number of sectors on the disk.

    Example: 1172123568

  `self_encrypting: bool GET`

    The self_encrypting field of the disk.

  `serial_number: str GET`

    The serial_number field of the disk.

    Example: KHG2VX8R

  `shelf: Shelf GET`

    The shelf field of the disk.

  `state: str GET POST PATCH`

    State

    Valid choices:

    - broken
    - copy
    - maintenance
    - partner
    - pending
    - present
    - reconstructing
    - removed
    - spare
    - unfail
    - zeroing
  `stats: DiskStats GET POST PATCH`

    The stats field of the disk.

  `storage_availability_zone: StorageAvailabilityZone GET`

    The storage_availability_zone field of the disk.

  `storage_pool: StoragePool GET`

    The storage_pool field of the disk.

  `type: str GET`

    Disk interface type

    Valid choices:

    - ata
    - bsas
    - fcal
    - fsas
    - lun
    - sas
    - msata
    - ssd
    - vmdisk
    - unknown
    - ssd_cap
    - ssd_nvm
    - ssd_zns
  `uid: str GET`

    The unique identifier for a disk

    Example: 002538E5:71B00B2F:00000000:00000000:00000000:00000000:00000000:00000000:00000000:00000000

  `usable_size: Size GET`

    The usable_size field of the disk.

    Example: 959934889984

  `vendor: str GET`

    The vendor field of the disk.

    Example: NETAPP

  `virtual: DiskVirtual GET POST PATCH`

    Information about backing storage for disks on cloud platforms.